@@ -27,9 +27,9 @@ class TrainerNode(Node):
         self.latest_known_model_id = None
 
         @self.sio_client.on('begin_training')
-        async def on_begin_training(organization, project, source_model):
+        async def on_begin_training(organization: str, project: str, details: dict):
             loop = asyncio.get_event_loop()
-            loop.create_task(self.begin_training(Context(organization=organization, project=project), source_model))
+            loop.create_task(self.begin_training(Context(organization=organization, project=project), details))
             return True
 
         @self.sio_client.on('stop_training')
@@ -58,11 +58,11 @@ class TrainerNode(Node):
                 logging.exception('could not kill training.')
                 pass
 
-    async def begin_training(self, context: Context, source_model: dict):
+    async def begin_training(self, context: Context, details: dict):
         self.status.reset_error('start_training')
         await self.update_state(State.Preparing)
         try:
-            await self.trainer.begin_training(context, source_model)
+            await self.trainer.begin_training(context, details)
         except Exception as e:
             self.status.set_error('start_training', f'Could not start training: {str(e)})')
 
@@ -71,7 +71,7 @@ class TrainerNode(Node):
             await self.update_state(State.Idle)
             return
         # NOTE 'id' can also be a well known pretrained model identifier.
-        self.latest_known_model_id = source_model['id'] if is_valid_uuid4(source_model['id']) else None
+        self.latest_known_model_id = details['id'] if is_valid_uuid4(details['id']) else None
         await self.update_state(State.Running)
 
     async def stop_training(self, do_detections: bool = True, save_latest_model: bool = True) -> Union[bool, str]:
@@ -83,7 +83,8 @@ class TrainerNode(Node):
 
         try:
             result = self.trainer.stop_training()
-            if self.latest_known_model_id and self.trainer.source_model_id != self.latest_known_model_id:
+
+            if self.latest_known_model_id and self.trainer.training.base_model_id != self.latest_known_model_id:
                 if save_latest_model:
                     await self.update_state(State.Uploading)
                     await self.save_model(self.trainer.training.context, self.latest_known_model_id)
@@ -173,6 +174,7 @@ class TrainerNode(Node):
                         train_image_count=current_training.data.train_image_count(),
                         test_image_count=current_training.data.test_image_count(),
                         trainer_id=self.uuid,
+                        hyperparameters=self.trainer.hyperparameters
                     )
 
                     result = await self.sio_client.call('update_model', (current_training.context.organization, current_training.context.project, jsonable_encoder(new_model)))
@@ -200,8 +202,9 @@ class TrainerNode(Node):
             id=self.uuid,
             name=self.name,
             state=self.status.state,
-            uptime=int((datetime.now() - self.startup_time).total_seconds()),
-            errors=self.status._errors
+            uptime=self.training_uptime,
+            errors=self.status._errors,
+            progress=self.progress
         )
         # TODO can self.trainer be None?
         if self.trainer:
@@ -211,6 +214,7 @@ class TrainerNode(Node):
             status.train_image_count = self.trainer.training.data.train_image_count()
             status.test_image_count = self.trainer.training.data.test_image_count()
             status.skipped_image_count = self.trainer.training.data.skipped_image_count
+            status.hyperparameters = self.trainer.hyperparameters
 
         logging.info(f'sending status {status}')
         result = await self.sio_client.call('update_trainer', jsonable_encoder(status), timeout=1)
@@ -229,3 +233,13 @@ class TrainerNode(Node):
         if self.trainer.executor is not None and self.trainer.executor.is_process_running():
             return State.Running
         return State.Idle
+
+    @property
+    def progress(self) -> Union[float, None]:
+        return self.trainer.progress if hasattr(self.trainer, 'progress') else None
+
+    @property
+    def training_uptime(self) -> Union[int, None]:
+        import time
+        now = time.time()
+        return now - self.trainer.start_time if self.trainer.start_time else None
